@@ -9,7 +9,7 @@
 #include "stacer-core_global.h"
 
 // Run command in English language (guarantee same behaviour across languages)
-#define LSCPU_COMMAND "LANG=en_US.UTF-8 lscpu"
+#define LSCPU_COMMAND "LC_ALL=C lscpu"
 #define PROC_CPUINFO "/proc/cpuinfo"
 
 class STACERCORESHARED_EXPORT SystemInfo
