@@ -9,9 +9,6 @@
 #define APT_SOURCES_LIST_D_PATH "/etc/apt/sources.list.d"
 #define APT_SOURCES_LIST_PATH "/etc/apt/sources.list"
 
-// isSource options uri distribution componentes
-// example "deb [arch=amd64] http://packages.microsoft.com/repos/vscode stable main"
-
 class APTSource
 {
   public:
@@ -19,7 +16,7 @@ class APTSource
     bool isSource;
     QString options;
     QString uri;
-    QString distribution;
+    QString suites;
     QString components;
 
     QString source;
@@ -35,7 +32,7 @@ class AptSourceTool
     static QList<APTSourcePtr> getSourceList();
     static void removeAPTSource(const APTSourcePtr aptSource);
     static void changeStatus(const APTSourcePtr aptSource, const bool status);
-    static void changeSource(const APTSourcePtr aptSource, const QString newSource);
+    static void changeSource(const APTSourcePtr aptSource, const APTSourcePtr newSource);
     static void addRepository(const QString &repository, const bool isSource);
 };
 
