@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="cs_CZ">
+<TS version="2.1" language="cs_CZ" sourcelanguage="en">
 <context>
     <name>APTSourceEdit</name>
     <message>
@@ -45,8 +45,8 @@
     </message>
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="133"/>
-        <source>Distribution</source>
-        <translation>Distribuce</translation>
+        <source>Suites</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="152"/>
@@ -93,7 +93,7 @@
     </message>
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="338"/>
-        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="85"/>
+        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="95"/>
         <source>Add Repository</source>
         <translation>Přidat repozitář</translation>
     </message>
@@ -113,15 +113,20 @@
         <translation>příklad %1</translation>
     </message>
     <message>
-        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="58"/>
+        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="63"/>
         <source>APT Repositories (%1)</source>
         <translation>Repozitáře APT (%1)</translation>
     </message>
     <message>
-        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="65"/>
+        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="69"/>
         <source>Save</source>
         <translation>Uložit</translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="75"/>
+        <source>Adding...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>APTSourceRepositoryItem</name>
@@ -149,9 +154,9 @@
         <translation>Čistič systému</translation>
     </message>
     <message>
-        <location filename="../stacer/app.ui" line="362"/>
-        <source>APT Repository Manager</source>
-        <translation>Správce repozitářů APT</translation>
+        <location filename="../stacer/app.ui" line="194"/>
+        <source>Search</source>
+        <translation>Hledat</translation>
     </message>
     <message>
         <location filename="../stacer/app.ui" line="278"/>
@@ -163,26 +168,26 @@
         <source>Resources</source>
         <translation>Prostředky</translation>
     </message>
+    <message>
+        <location filename="../stacer/app.ui" line="334"/>
+        <source>Helpers</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../stacer/app.ui" line="362"/>
+        <source>APT Repository Manager</source>
+        <translation>Správce repozitářů APT</translation>
+    </message>
     <message>
         <location filename="../stacer/app.ui" line="250"/>
         <source>Processes</source>
         <translation>Procesy</translation>
     </message>
-    <message>
-        <location filename="../stacer/app.ui" line="194"/>
-        <source>Search</source>
-        <translation>Hledat</translation>
-    </message>
     <message>
         <location filename="../stacer/app.ui" line="222"/>
         <source>Services</source>
         <translation>Služby</translation>
     </message>
-    <message>
-        <location filename="../stacer/app.ui" line="334"/>
-        <source>Helpers</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/app.ui" line="390"/>
         <source>Gnome Settings</source>
@@ -201,7 +206,7 @@
     <message>
         <location filename="../stacer/app.cpp" line="108"/>
         <location filename="../stacer/app.cpp" line="115"/>
-        <location filename="../stacer/app.cpp" line="168"/>
+        <location filename="../stacer/app.cpp" line="173"/>
         <source>Quit</source>
         <translation>Zavřít</translation>
     </message>
@@ -210,6 +215,11 @@
         <source>Continue</source>
         <translation>Pokračovat</translation>
     </message>
+    <message>
+        <location filename="../stacer/app.cpp" line="113"/>
+        <source>Don&apos;t ask again.</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../stacer/app.cpp" line="116"/>
         <source>Will the program continue to work in the system tray?</source>
@@ -341,6 +351,26 @@
         <source>CPU</source>
         <translation>PROCESOR</translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="19"/>
+        <source>MEMORY</source>
+        <translation>PAMĚŤ</translation>
+    </message>
+    <message>
+        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="20"/>
+        <source>DISK</source>
+        <translation>DISK</translation>
+    </message>
+    <message>
+        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="21"/>
+        <source>DOWNLOAD</source>
+        <translation>STAHOVÁNÍ</translation>
+    </message>
+    <message>
+        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="22"/>
+        <source>UPLOAD</source>
+        <translation>NAHRÁVÁNÍ</translation>
+    </message>
     <message>
         <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="111"/>
         <source>Hostname: %1</source>
@@ -366,35 +396,15 @@
         <source>CPU Model: %1</source>
         <translation>Model procesoru: %1</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="117"/>
-        <source>CPU Speed: %1</source>
-        <translation>Frekvence procesoru: %1</translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="116"/>
         <source>CPU Core: %1</source>
         <translation>Jádra procesoru: %1</translation>
     </message>
     <message>
-        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="19"/>
-        <source>MEMORY</source>
-        <translation>PAMĚŤ</translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="20"/>
-        <source>DISK</source>
-        <translation>DISK</translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="21"/>
-        <source>DOWNLOAD</source>
-        <translation>STAHOVÁNÍ</translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="22"/>
-        <source>UPLOAD</source>
-        <translation>NAHRÁVÁNÍ</translation>
+        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="117"/>
+        <source>CPU Speed: %1</source>
+        <translation>Frekvence procesoru: %1</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="135"/>
@@ -455,11 +465,6 @@
         <source>Send</source>
         <translation>Odeslat</translation>
     </message>
-    <message>
-        <location filename="../stacer/feedback.ui" line="117"/>
-        <source>danger</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/feedback.ui" line="120"/>
         <source>Close</source>
@@ -483,7 +488,7 @@
     <message>
         <location filename="../stacer/feedback.cpp" line="51"/>
         <source>Your message must be at least 5 characters !</source>
-        <translation>Vaše zpráva musí být delší než 25 znaků! {5 ?}</translation>
+        <translation>Vaše zpráva musí být delší než 5 znaků!</translation>
     </message>
     <message>
         <location filename="../stacer/feedback.cpp" line="59"/>
@@ -555,12 +560,6 @@
         <source>Form</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="60"/>
-        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="173"/>
-        <source>primary</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.ui" line="63"/>
         <source>Save Changes</source>
@@ -592,11 +591,6 @@
         <source>Save</source>
         <translation>Uložit</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="189"/>
-        <source>danger</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.ui" line="192"/>
         <source>Cancel</source>
@@ -831,23 +825,6 @@
         <source>Search...</source>
         <translation>Hledat...</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="145"/>
-        <source>primary</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="208"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="367"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="403"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="511"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="527"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="543"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="581"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="604"/>
-        <source>circle</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="211"/>
         <source>Case Insensitive</source>
@@ -1316,12 +1293,12 @@
         <translation>Přidat automatické spouštění aplikace</translation>
     </message>
     <message>
-        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="66"/>
+        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="67"/>
         <source>Startup Apps are disabled.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="126"/>
+        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="127"/>
         <source>Startup Applications (%1)</source>
         <translation>Automatické spuštění aplikací (%1)</translation>
     </message>
@@ -1364,12 +1341,6 @@
         <source>Select all</source>
         <translation>Vybrat vše</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="574"/>
-        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="635"/>
-        <source>circle</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="651"/>
         <source> Back</source>
@@ -1416,12 +1387,6 @@
         <source>Uninstaller</source>
         <translation>Odinstalovávač</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="78"/>
-        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="201"/>
-        <source>notFoundWidget</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="371"/>
         <source>System Packages</source>
