@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="de_DE">
+<TS version="2.1" language="de_DE" sourcelanguage="en_US">
 <context>
     <name>APTSourceEdit</name>
     <message>
@@ -31,7 +31,7 @@
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="87"/>
         <source>Fields cannot be left blank.</source>
-        <translation>Felder dürfen nicht leer gelassen werden. </translation>
+        <translation>Felder dürfen nicht leer gelassen werden.</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="94"/>
@@ -45,8 +45,8 @@
     </message>
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="133"/>
-        <source>Distribution</source>
-        <translation>Distribution</translation>
+        <source>Suites</source>
+        <translation>Suites</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="152"/>
@@ -56,7 +56,7 @@
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="177"/>
         <source>Binary</source>
-        <translation>Binary</translation>
+        <translation>Binär</translation>
     </message>
 </context>
 <context>
@@ -93,7 +93,7 @@
     </message>
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="338"/>
-        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="85"/>
+        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="95"/>
         <source>Add Repository</source>
         <translation>Paketquelle hinzufügen</translation>
     </message>
@@ -110,25 +110,30 @@
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="24"/>
         <source>example %1</source>
-        <translation>bspw. %1</translation>
+        <translation>Beispiel %1</translation>
     </message>
     <message>
-        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="58"/>
+        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="63"/>
         <source>APT Repositories (%1)</source>
         <translation>APT Paketquellen (%1)</translation>
     </message>
     <message>
-        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="65"/>
+        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="69"/>
         <source>Save</source>
         <translation>Speichern</translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="75"/>
+        <source>Adding...</source>
+        <translation>Hinzufügen...</translation>
+    </message>
 </context>
 <context>
     <name>APTSourceRepositoryItem</name>
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_repository_item.cpp" line="35"/>
         <source>%1 (Source Code)</source>
-        <translation>Sourcecode</translation>
+        <translation>%1 (Quellcode)</translation>
     </message>
 </context>
 <context>
@@ -141,7 +146,7 @@
     <message>
         <location filename="../stacer/app.ui" line="135"/>
         <source>Startup Apps</source>
-        <translation>Startprogramme</translation>
+        <translation>Autostart-Anwendungen</translation>
     </message>
     <message>
         <location filename="../stacer/app.ui" line="163"/>
@@ -149,9 +154,9 @@
         <translation>System-Reinigung</translation>
     </message>
     <message>
-        <location filename="../stacer/app.ui" line="362"/>
-        <source>APT Repository Manager</source>
-        <translation>APT Paketquellen-Verwaltung</translation>
+        <location filename="../stacer/app.ui" line="194"/>
+        <source>Search</source>
+        <translation>Suchen</translation>
     </message>
     <message>
         <location filename="../stacer/app.ui" line="278"/>
@@ -164,25 +169,25 @@
         <translation>Ressourcen</translation>
     </message>
     <message>
-        <location filename="../stacer/app.ui" line="250"/>
-        <source>Processes</source>
-        <translation>Systemressourcen</translation>
+        <location filename="../stacer/app.ui" line="334"/>
+        <source>Helpers</source>
+        <translation>Helfer</translation>
     </message>
     <message>
-        <location filename="../stacer/app.ui" line="194"/>
-        <source>Search</source>
-        <translation>Suchen</translation>
+        <location filename="../stacer/app.ui" line="362"/>
+        <source>APT Repository Manager</source>
+        <translation>APT Paketquellen-Verwaltung</translation>
+    </message>
+    <message>
+        <location filename="../stacer/app.ui" line="250"/>
+        <source>Processes</source>
+        <translation>Prozesse</translation>
     </message>
     <message>
         <location filename="../stacer/app.ui" line="222"/>
         <source>Services</source>
         <translation>Dienste</translation>
     </message>
-    <message>
-        <location filename="../stacer/app.ui" line="334"/>
-        <source>Helpers</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/app.ui" line="390"/>
         <source>Gnome Settings</source>
@@ -201,7 +206,7 @@
     <message>
         <location filename="../stacer/app.cpp" line="108"/>
         <location filename="../stacer/app.cpp" line="115"/>
-        <location filename="../stacer/app.cpp" line="168"/>
+        <location filename="../stacer/app.cpp" line="173"/>
         <source>Quit</source>
         <translation>Beenden</translation>
     </message>
@@ -210,6 +215,11 @@
         <source>Continue</source>
         <translation>Fortsetzen</translation>
     </message>
+    <message>
+        <location filename="../stacer/app.cpp" line="113"/>
+        <source>Don&apos;t ask again.</source>
+        <translation>Frag nicht nochmal.</translation>
+    </message>
     <message>
         <location filename="../stacer/app.cpp" line="116"/>
         <source>Will the program continue to work in the system tray?</source>
@@ -226,7 +236,7 @@
     <message>
         <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="74"/>
         <source>Screen Reader</source>
-        <translation>Screenreader</translation>
+        <translation>Bildschirmleser</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="100"/>
@@ -256,7 +266,7 @@
     <message>
         <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="282"/>
         <source>Home Icon</source>
-        <translation>Home-Icon</translation>
+        <translation>Home-Symbol</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="308"/>
@@ -266,12 +276,12 @@
     <message>
         <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="321"/>
         <source>Mounted Volumes Icon</source>
-        <translation>Laufwerke-Icon</translation>
+        <translation>Eingebundenes Laufwerks-Symbol</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="347"/>
         <source>Show Desktop Icons</source>
-        <translation>Desktop-Anzeigen-Icon</translation>
+        <translation>Desktop-Anzeige-Symbol</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="373"/>
@@ -341,6 +351,26 @@
         <source>CPU</source>
         <translation>CPU</translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="19"/>
+        <source>MEMORY</source>
+        <translation>ARBEITSSPEICHER</translation>
+    </message>
+    <message>
+        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="20"/>
+        <source>DISK</source>
+        <translation>FESTPLATTE</translation>
+    </message>
+    <message>
+        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="21"/>
+        <source>DOWNLOAD</source>
+        <translation>DOWNLOAD</translation>
+    </message>
+    <message>
+        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="22"/>
+        <source>UPLOAD</source>
+        <translation>UPLOAD</translation>
+    </message>
     <message>
         <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="111"/>
         <source>Hostname: %1</source>
@@ -366,35 +396,15 @@
         <source>CPU Model: %1</source>
         <translation>CPU Modell: %1</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="117"/>
-        <source>CPU Speed: %1</source>
-        <translation>CPU Frequenz: %1</translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="116"/>
         <source>CPU Core: %1</source>
         <translation>CPU Kerne: %1</translation>
     </message>
     <message>
-        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="19"/>
-        <source>MEMORY</source>
-        <translation>ARBEITSSPEICHER</translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="20"/>
-        <source>DISK</source>
-        <translation>FESTPLATTE</translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="21"/>
-        <source>DOWNLOAD</source>
-        <translation>DOWNLOAD</translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="22"/>
-        <source>UPLOAD</source>
-        <translation>UPLOAD</translation>
+        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="117"/>
+        <source>CPU Speed: %1</source>
+        <translation>CPU Frequenz: %1</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="135"/>
@@ -438,7 +448,7 @@
     <message>
         <location filename="../stacer/feedback.ui" line="14"/>
         <source>Feedback</source>
-        <translation>Feedback</translation>
+        <translation>Rückmeldung</translation>
     </message>
     <message>
         <location filename="../stacer/feedback.ui" line="61"/>
@@ -455,15 +465,10 @@
         <source>Send</source>
         <translation>Senden</translation>
     </message>
-    <message>
-        <location filename="../stacer/feedback.ui" line="117"/>
-        <source>danger</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/feedback.ui" line="120"/>
         <source>Close</source>
-        <translation type="unfinished"></translation>
+        <translation>Schließen</translation>
     </message>
     <message>
         <location filename="../stacer/feedback.ui" line="54"/>
@@ -473,17 +478,17 @@
     <message>
         <location filename="../stacer/feedback.ui" line="78"/>
         <source>Send feedback</source>
-        <translation>Feedback senden</translation>
+        <translation>Rückmeldung senden</translation>
     </message>
     <message>
         <location filename="../stacer/feedback.cpp" line="46"/>
         <source>Email address is not valid !</source>
-        <translation>Keine gültige E-Mail Adresse</translation>
+        <translation>Keine gültige E-Mail Adresse!</translation>
     </message>
     <message>
         <location filename="../stacer/feedback.cpp" line="51"/>
         <source>Your message must be at least 5 characters !</source>
-        <translation>Ihre Nachricht muss mindestens 25 Zeichen betragen! {5 ?}</translation>
+        <translation>Ihre Nachricht muss mindestens 5 Zeichen betragen!</translation>
     </message>
     <message>
         <location filename="../stacer/feedback.cpp" line="59"/>
@@ -493,7 +498,7 @@
     <message>
         <location filename="../stacer/feedback.cpp" line="78"/>
         <source>&lt;font color=&apos;#2ecc71&apos;&gt;Your feedback has been successfully sent. Thanks!&lt;/font&gt;</source>
-        <translation>&lt;font color=&apos;#2ecc71&apos;&gt;Dein Feedback wurde erfolgreich versandt.&lt;/font&gt;</translation>
+        <translation>&lt;font color=&apos;#2ecc71&apos;&gt;Deine Rückmeldung wurde erfolgreich versandt.&lt;/font&gt;</translation>
     </message>
     <message>
         <location filename="../stacer/feedback.cpp" line="80"/>
@@ -509,7 +514,7 @@
     <message>
         <location filename="../stacer/feedback.cpp" line="93"/>
         <source>Fields cannot be left blank !</source>
-        <translation>Felder dürfen nicht leer gelassen werden</translation>
+        <translation>Felder dürfen nicht leer gelassen werden!</translation>
     </message>
 </context>
 <context>
@@ -540,12 +545,12 @@
     <message>
         <location filename="../stacer/Pages/Helpers/helpers_page.ui" line="14"/>
         <source>Helpers</source>
-        <translation type="unfinished"></translation>
+        <translation>Helfer</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Helpers/helpers_page.ui" line="62"/>
         <source>Host Manage</source>
-        <translation type="unfinished"></translation>
+        <translation>Rechnerverwaltung</translation>
     </message>
 </context>
 <context>
@@ -553,50 +558,39 @@
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.ui" line="14"/>
         <source>Form</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="60"/>
-        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="173"/>
-        <source>primary</source>
-        <translation type="unfinished"></translation>
+        <translation>Formular</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.ui" line="63"/>
         <source>Save Changes</source>
-        <translation type="unfinished"></translation>
+        <translation>Änderungen speichern</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.ui" line="110"/>
         <source>New Host</source>
-        <translation type="unfinished"></translation>
+        <translation>Neuer Rechner</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.ui" line="146"/>
         <source>IP Address *</source>
-        <translation type="unfinished"></translation>
+        <translation>IP-Adresse *</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.ui" line="153"/>
         <source>Fully Qualified Name *</source>
-        <translation type="unfinished"></translation>
+        <translation>Vollständig qualifizierter Name *</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.ui" line="160"/>
         <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="39"/>
         <source>Aliases</source>
-        <translation type="unfinished"></translation>
+        <translation>Aliase</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.ui" line="176"/>
         <source>Save</source>
         <translation>Speichern</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="189"/>
-        <source>danger</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.ui" line="192"/>
         <source>Cancel</source>
@@ -606,17 +600,17 @@
         <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="26"/>
         <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="100"/>
         <source>Hosts (%1)</source>
-        <translation type="unfinished"></translation>
+        <translation>Rechner (%1)</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="39"/>
         <source>IP Address</source>
-        <translation type="unfinished"></translation>
+        <translation>IP-Adresse</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="39"/>
         <source>Full Qualified</source>
-        <translation type="unfinished"></translation>
+        <translation>Qualifizerter Name</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="137"/>
@@ -631,7 +625,7 @@
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="149"/>
         <source>The IP and Fully Qualified fields are required.</source>
-        <translation type="unfinished"></translation>
+        <translation>Die IP und qualifizierte Felder werden benötigt.</translation>
     </message>
 </context>
 <context>
@@ -705,7 +699,7 @@
     <message>
         <location filename="../stacer/Pages/Processes/processes_page.cpp" line="31"/>
         <source>Session</source>
-        <translation>Session</translation>
+        <translation>Sitzung</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Processes/processes_page.cpp" line="31"/>
@@ -761,17 +755,17 @@
     <message>
         <location filename="../stacer/Pages/Resources/resources_page.cpp" line="106"/>
         <source>File System</source>
-        <translation type="unfinished"></translation>
+        <translation>Dateisystem</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Resources/resources_page.cpp" line="122"/>
         <source>File System Type</source>
-        <translation type="unfinished"></translation>
+        <translation>Dateisystemtyp</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Resources/resources_page.cpp" line="142"/>
         <source>Device</source>
-        <translation type="unfinished"></translation>
+        <translation>Geräte</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Resources/resources_page.cpp" line="217"/>
@@ -824,59 +818,42 @@
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="101"/>
         <source>Browse...</source>
-        <translation type="unfinished"></translation>
+        <translation>Durchsuchen...</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="113"/>
         <source>Search...</source>
         <translation>Suchen...</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="145"/>
-        <source>primary</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="208"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="367"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="403"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="511"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="527"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="543"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="581"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="604"/>
-        <source>circle</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="211"/>
         <source>Case Insensitive</source>
-        <translation type="unfinished"></translation>
+        <translation>Groß-/Kleinschreibung</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="298"/>
         <source> minute</source>
-        <translation type="unfinished"></translation>
+        <translation> Minute</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="370"/>
         <source>Search as Root</source>
-        <translation type="unfinished"></translation>
+        <translation>Als Systemverwalter suchen</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="377"/>
         <source>Owner</source>
-        <translation type="unfinished"></translation>
+        <translation>Eigentümer</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="406"/>
         <source>RegEx</source>
-        <translation type="unfinished"></translation>
+        <translation>Regulärer Ausdruck</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="483"/>
         <source>Permissions</source>
-        <translation type="unfinished"></translation>
+        <translation>Rechte</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="490"/>
@@ -887,47 +864,47 @@
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="514"/>
         <source>Readable</source>
-        <translation type="unfinished"></translation>
+        <translation>Lesbar</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="530"/>
         <source>Writable</source>
-        <translation type="unfinished"></translation>
+        <translation>Schreibbar</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="546"/>
         <source>Executable</source>
-        <translation type="unfinished"></translation>
+        <translation>Ausführbar</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="555"/>
         <source>Time</source>
-        <translation type="unfinished"></translation>
+        <translation>Zeit</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="584"/>
         <source>Empty</source>
-        <translation type="unfinished"></translation>
+        <translation>Leer</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="591"/>
         <source>File or Folder:</source>
-        <translation type="unfinished"></translation>
+        <translation>Datei oder Ordner:</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="607"/>
         <source>Invert</source>
-        <translation type="unfinished"></translation>
+        <translation>Invertieren</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="650"/>
         <source>Advanced Search</source>
-        <translation type="unfinished"></translation>
+        <translation>Erweiterte Suche</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="690"/>
         <source>BETA version</source>
-        <translation type="unfinished"></translation>
+        <translation>BETA-Version</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="25"/>
@@ -937,7 +914,7 @@
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="26"/>
         <source>Path</source>
-        <translation type="unfinished"></translation>
+        <translation>Pfad</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="28"/>
@@ -952,32 +929,32 @@
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="30"/>
         <source>Creation Time</source>
-        <translation type="unfinished"></translation>
+        <translation>Erstellungszeit</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="31"/>
         <source>Last Access</source>
-        <translation type="unfinished"></translation>
+        <translation>Letzter Zugriff</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="32"/>
         <source>Last Modification</source>
-        <translation type="unfinished"></translation>
+        <translation>Letzte Modifikation</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="33"/>
         <source>Last Change</source>
-        <translation type="unfinished"></translation>
+        <translation>Letzte Änderung</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="88"/>
         <source>Open Folder</source>
-        <translation type="unfinished"></translation>
+        <translation>Öffne Ordner</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="92"/>
         <source>Move Trash</source>
-        <translation type="unfinished"></translation>
+        <translation>Papierkorb verschieben</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="96"/>
@@ -990,90 +967,90 @@
         <location filename="../stacer/Pages/Search/search_page.cpp" line="140"/>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="149"/>
         <source>Choose</source>
-        <translation type="unfinished"></translation>
+        <translation>Wähle</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="135"/>
         <source>All</source>
-        <translation type="unfinished"></translation>
+        <translation>Alle</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="136"/>
         <source>File</source>
-        <translation type="unfinished"></translation>
+        <translation>Datei</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="137"/>
         <source>Directory</source>
-        <translation type="unfinished"></translation>
+        <translation>Verzeichnis</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="138"/>
         <source>Symbolic Link</source>
-        <translation type="unfinished"></translation>
+        <translation>Symbolischer Link</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="141"/>
         <source>Access</source>
-        <translation type="unfinished"></translation>
+        <translation>Zugriff</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="142"/>
         <source>Modify</source>
-        <translation type="unfinished"></translation>
+        <translation>Modifikation</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="143"/>
         <source>Change</source>
-        <translation type="unfinished"></translation>
+        <translation>Änderung</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="145"/>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="150"/>
         <source>Smaller (&lt;)</source>
-        <translation type="unfinished"></translation>
+        <translation>Kleiner (&lt;)</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="146"/>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="151"/>
         <source>Equal (=)</source>
-        <translation type="unfinished"></translation>
+        <translation>Gleich (=)</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="147"/>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="152"/>
         <source>Greater (&gt;)</source>
-        <translation type="unfinished"></translation>
+        <translation>Größer (&gt;)</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="162"/>
         <source>Select Directory</source>
-        <translation type="unfinished"></translation>
+        <translation>Wähle das Verzeichnis</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="168"/>
         <source>Directory: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Verzeichnis: %1</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="177"/>
         <source>Advanced Search %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Erweiterte Suche %1</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="195"/>
         <source>Select the search directory.</source>
-        <translation type="unfinished"></translation>
+        <translation>Wählen Sie das zu durchsuchende Verzeichnis.</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="293"/>
         <source>Somethings went wrong, try again.</source>
-        <translation type="unfinished"></translation>
+        <translation>Etwas lief schief, versuchen Sie es erneut.</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="309"/>
         <source>%1 files found. Showing %2 of them.</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 Dateien gefunden. Zeige %2 von ihnen.</translation>
     </message>
 </context>
 <context>
@@ -1154,7 +1131,7 @@
     <message>
         <location filename="../stacer/Pages/Settings/settings_page.ui" line="329"/>
         <source>App Quit Don&apos;t Ask</source>
-        <translation type="unfinished"></translation>
+        <translation>Anwendung ohne Rückfrage verlassen</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Settings/settings_page.ui" line="389"/>
@@ -1199,7 +1176,7 @@
     <message>
         <location filename="../stacer/Pages/Settings/settings_page.cpp" line="83"/>
         <source>Startup Apps</source>
-        <translation>Startprogramme</translation>
+        <translation>Autostart-Programme</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Settings/settings_page.cpp" line="83"/>
@@ -1234,7 +1211,7 @@
     <message>
         <location filename="../stacer/Pages/Settings/settings_page.cpp" line="84"/>
         <source>Helpers</source>
-        <translation type="unfinished"></translation>
+        <translation>Helfer</translation>
     </message>
 </context>
 <context>
@@ -1265,7 +1242,7 @@
     <message>
         <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="44"/>
         <source>Fields cannot be left blank.</source>
-        <translation>Feld darf nicht leer gelassen werden. </translation>
+        <translation>Feld darf nicht leer gelassen werden.</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="65"/>
@@ -1280,12 +1257,12 @@
     <message>
         <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="58"/>
         <source>Generic Name</source>
-        <translation type="unfinished"></translation>
+        <translation>Generischer Name</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="72"/>
         <source>App Icon</source>
-        <translation type="unfinished"></translation>
+        <translation>Anwendungssymbol</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="79"/>
@@ -1316,12 +1293,12 @@
         <translation>Startprogramm hinzufügen</translation>
     </message>
     <message>
-        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="66"/>
+        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="67"/>
         <source>Startup Apps are disabled.</source>
-        <translation type="unfinished"></translation>
+        <translation>Autostart-Anwendungen sind ausgesetzt.</translation>
     </message>
     <message>
-        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="126"/>
+        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="127"/>
         <source>Startup Applications (%1)</source>
         <translation>Startprogramme (%1)</translation>
     </message>
@@ -1364,12 +1341,6 @@
         <source>Select all</source>
         <translation>Alle auswählen</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="574"/>
-        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="635"/>
-        <source>circle</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="651"/>
         <source> Back</source>
@@ -1378,7 +1349,7 @@
     <message>
         <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="759"/>
         <source>Sort by: </source>
-        <translation type="unfinished"></translation>
+        <translation>Sortierung: </translation>
     </message>
     <message>
         <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="773"/>
@@ -1394,7 +1365,7 @@
     <message>
         <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.cpp" line="180"/>
         <source>Total size: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Gesamtgröße: %1</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="791"/>
@@ -1416,21 +1387,15 @@
         <source>Uninstaller</source>
         <translation>Paket-Deinstallation</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="78"/>
-        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="201"/>
-        <source>notFoundWidget</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="371"/>
         <source>System Packages</source>
-        <translation type="unfinished"></translation>
+        <translation>Systempakete</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="393"/>
         <source>Snap Packages</source>
-        <translation type="unfinished"></translation>
+        <translation>Snap Pakete</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="442"/>
@@ -1446,23 +1411,23 @@
     <message>
         <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="340"/>
         <source>Uninstall Selected</source>
-        <translation>Ausgewähltes deinstallieren</translation>
+        <translation>Ausgewählte deinstallieren</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Uninstaller/uninstaller_page.cpp" line="102"/>
         <source>Packages (%1)</source>
-        <translation type="unfinished"></translation>
+        <translation>Pakete (%1)</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Uninstaller/uninstaller_page.cpp" line="107"/>
         <source>Snap Packages (%1)</source>
-        <translation type="unfinished"></translation>
+        <translation>Snap Pakete (%1)</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Uninstaller/uninstaller_page.cpp" line="208"/>
         <location filename="../stacer/Pages/Uninstaller/uninstaller_page.cpp" line="215"/>
         <source>Uninstall Selected (%1)</source>
-        <translation type="unfinished"></translation>
+        <translation>De-Installiere ausgewählte (%1)</translation>
     </message>
 </context>
 <context>
