@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="hi_IN">
+<TS version="2.1" language="hi_IN" sourcelanguage="en">
 <context>
     <name>APTSourceEdit</name>
     <message>
@@ -26,7 +26,7 @@
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="71"/>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">रद्द करें</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="87"/>
@@ -45,13 +45,13 @@
     </message>
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="133"/>
-        <source>Distribution</source>
+        <source>Suites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="152"/>
         <source>Source</source>
-        <translation type="unfinished"></translation>
+        <translation>स्रोत</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="177"/>
@@ -93,14 +93,14 @@
     </message>
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="338"/>
-        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="85"/>
+        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="95"/>
         <source>Add Repository</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="371"/>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>रद्द करें</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="419"/>
@@ -113,15 +113,20 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="58"/>
+        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="63"/>
         <source>APT Repositories (%1)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="65"/>
+        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="69"/>
         <source>Save</source>
         <translation>बचाना</translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="75"/>
+        <source>Adding...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>APTSourceRepositoryItem</name>
@@ -149,9 +154,9 @@
         <translation>सिस्टम क्लीनर</translation>
     </message>
     <message>
-        <location filename="../stacer/app.ui" line="362"/>
-        <source>APT Repository Manager</source>
-        <translation type="unfinished"></translation>
+        <location filename="../stacer/app.ui" line="194"/>
+        <source>Search</source>
+        <translation>खोजें</translation>
     </message>
     <message>
         <location filename="../stacer/app.ui" line="278"/>
@@ -163,26 +168,26 @@
         <source>Resources</source>
         <translation>साधन</translation>
     </message>
+    <message>
+        <location filename="../stacer/app.ui" line="334"/>
+        <source>Helpers</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../stacer/app.ui" line="362"/>
+        <source>APT Repository Manager</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../stacer/app.ui" line="250"/>
         <source>Processes</source>
         <translation>प्रक्रियाओं</translation>
     </message>
-    <message>
-        <location filename="../stacer/app.ui" line="194"/>
-        <source>Search</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/app.ui" line="222"/>
         <source>Services</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../stacer/app.ui" line="334"/>
-        <source>Helpers</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/app.ui" line="390"/>
         <source>Gnome Settings</source>
@@ -201,13 +206,18 @@
     <message>
         <location filename="../stacer/app.cpp" line="108"/>
         <location filename="../stacer/app.cpp" line="115"/>
-        <location filename="../stacer/app.cpp" line="168"/>
+        <location filename="../stacer/app.cpp" line="173"/>
         <source>Quit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../stacer/app.cpp" line="110"/>
         <source>Continue</source>
+        <translation>जारी रखें</translation>
+    </message>
+    <message>
+        <location filename="../stacer/app.cpp" line="113"/>
+        <source>Don&apos;t ask again.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -301,7 +311,7 @@
     <message>
         <location filename="../stacer/Pages/GnomeSettings/appearance_settings.cpp" line="71"/>
         <source>Stretched</source>
-        <translation type="unfinished"></translation>
+        <translation>खींचा हुआ</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/GnomeSettings/appearance_settings.cpp" line="71"/>
@@ -386,16 +396,16 @@
         <source>CPU Model: %1</source>
         <translation>CPU आदर्श: %1</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="117"/>
-        <source>CPU Speed: %1</source>
-        <translation>CPU गति: %1</translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="116"/>
         <source>CPU Core: %1</source>
         <translation>CPU कोर: %1</translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="117"/>
+        <source>CPU Speed: %1</source>
+        <translation>CPU गति: %1</translation>
+    </message>
     <message>
         <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="135"/>
         <source>High CPU Usage</source>
@@ -455,11 +465,6 @@
         <source>Send</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../stacer/feedback.ui" line="117"/>
-        <source>danger</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/feedback.ui" line="120"/>
         <source>Close</source>
@@ -555,12 +560,6 @@
         <source>Form</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="60"/>
-        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="173"/>
-        <source>primary</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.ui" line="63"/>
         <source>Save Changes</source>
@@ -592,15 +591,10 @@
         <source>Save</source>
         <translation>बचाना</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="189"/>
-        <source>danger</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.ui" line="192"/>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">रद्द करें</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="26"/>
@@ -657,6 +651,11 @@
         <source>End Process</source>
         <translation>प्रक्रिया समाप्त</translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="30"/>
+        <source>User</source>
+        <translation>उपयोगकर्ता</translation>
+    </message>
     <message>
         <location filename="../stacer/Pages/Processes/processes_page.cpp" line="29"/>
         <source>Resident Memory</source>
@@ -672,11 +671,6 @@
         <source>Virtual Memory</source>
         <translation>अप्रत्यक्ष स्मृति</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="30"/>
-        <source>User</source>
-        <translation>उपयोगकर्ता</translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Processes/processes_page.cpp" line="30"/>
         <source>Start Time</source>
@@ -819,7 +813,7 @@
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="14"/>
         <source>Search</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">खोजें</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="101"/>
@@ -831,23 +825,6 @@
         <source>Search...</source>
         <translation>खोज...</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="145"/>
-        <source>primary</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="208"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="367"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="403"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="511"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="527"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="543"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="581"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="604"/>
-        <source>circle</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="211"/>
         <source>Case Insensitive</source>
@@ -1209,7 +1186,7 @@
     <message>
         <location filename="../stacer/Pages/Settings/settings_page.cpp" line="83"/>
         <source>Search</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">खोजें</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/Settings/settings_page.cpp" line="84"/>
@@ -1300,6 +1277,11 @@
 </context>
 <context>
     <name>StartupAppsPage</name>
+    <message>
+        <location filename="../stacer/Pages/StartupApps/startup_apps_page.ui" line="201"/>
+        <source>Not Found Startup Apps</source>
+        <translation>स्टार्टअप ऐप्स नहीं मिला</translation>
+    </message>
     <message>
         <location filename="../stacer/Pages/StartupApps/startup_apps_page.ui" line="14"/>
         <source>Startup Apps</source>
@@ -1311,17 +1293,12 @@
         <translation>स्टार्टअप ऐप जोड़ें</translation>
     </message>
     <message>
-        <location filename="../stacer/Pages/StartupApps/startup_apps_page.ui" line="201"/>
-        <source>Not Found Startup Apps</source>
-        <translation>स्टार्टअप ऐप्स नहीं मिला</translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="66"/>
+        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="67"/>
         <source>Startup Apps are disabled.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="126"/>
+        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="127"/>
         <source>Startup Applications (%1)</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1364,12 +1341,6 @@
         <source>Select all</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="574"/>
-        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="635"/>
-        <source>circle</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="651"/>
         <source> Back</source>
@@ -1411,28 +1382,11 @@
 </context>
 <context>
     <name>UninstallerPage</name>
-    <message>
-        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="340"/>
-        <source>Uninstall Selected</source>
-        <translation>स्थापना रद्द करें चयनित</translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="108"/>
-        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="231"/>
-        <source>Not Found Installed Packages</source>
-        <translation>स्थापित नहीं मिला संकुल</translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="14"/>
         <source>Uninstaller</source>
         <translation>अनइंस्टॉलर</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="78"/>
-        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="201"/>
-        <source>notFoundWidget</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="371"/>
         <source>System Packages</source>
@@ -1448,6 +1402,17 @@
         <source>Search...</source>
         <translation>खोज...</translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="108"/>
+        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="231"/>
+        <source>Not Found Installed Packages</source>
+        <translation>स्थापित नहीं मिला संकुल</translation>
+    </message>
+    <message>
+        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="340"/>
+        <source>Uninstall Selected</source>
+        <translation>स्थापना रद्द करें चयनित</translation>
+    </message>
     <message>
         <location filename="../stacer/Pages/Uninstaller/uninstaller_page.cpp" line="102"/>
         <source>Packages (%1)</source>
@@ -1490,7 +1455,7 @@
     <message>
         <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="186"/>
         <source>Search</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">खोजें</translation>
     </message>
     <message>
         <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="196"/>
