@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="sv_SE">
+<TS version="2.1" language="sv_SE" sourcelanguage="en">
 <context>
     <name>APTSourceEdit</name>
     <message>
@@ -45,8 +45,8 @@
     </message>
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="133"/>
-        <source>Distribution</source>
-        <translation>Distribution</translation>
+        <source>Suites</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="152"/>
@@ -93,7 +93,7 @@
     </message>
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="338"/>
-        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="85"/>
+        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="95"/>
         <source>Add Repository</source>
         <translation>Lägg till programkälla</translation>
     </message>
@@ -113,15 +113,20 @@
         <translation>exempel %1</translation>
     </message>
     <message>
-        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="58"/>
+        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="63"/>
         <source>APT Repositories (%1)</source>
         <translation>APT programkällor (%1)</translation>
     </message>
     <message>
-        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="65"/>
+        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="69"/>
         <source>Save</source>
         <translation>Spara</translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="75"/>
+        <source>Adding...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>APTSourceRepositoryItem</name>
@@ -149,9 +154,9 @@
         <translation>Systemrensare</translation>
     </message>
     <message>
-        <location filename="../stacer/app.ui" line="362"/>
-        <source>APT Repository Manager</source>
-        <translation>APT programkällor</translation>
+        <location filename="../stacer/app.ui" line="194"/>
+        <source>Search</source>
+        <translation>Sök</translation>
     </message>
     <message>
         <location filename="../stacer/app.ui" line="278"/>
@@ -163,26 +168,26 @@
         <source>Resources</source>
         <translation>Resurser</translation>
     </message>
+    <message>
+        <location filename="../stacer/app.ui" line="334"/>
+        <source>Helpers</source>
+        <translation>Hjälpare</translation>
+    </message>
+    <message>
+        <location filename="../stacer/app.ui" line="362"/>
+        <source>APT Repository Manager</source>
+        <translation>APT programkällor</translation>
+    </message>
     <message>
         <location filename="../stacer/app.ui" line="250"/>
         <source>Processes</source>
         <translation>Processer</translation>
     </message>
-    <message>
-        <location filename="../stacer/app.ui" line="194"/>
-        <source>Search</source>
-        <translation>Sök</translation>
-    </message>
     <message>
         <location filename="../stacer/app.ui" line="222"/>
         <source>Services</source>
         <translation>Tjänster</translation>
     </message>
-    <message>
-        <location filename="../stacer/app.ui" line="334"/>
-        <source>Helpers</source>
-        <translation>Hjälpare</translation>
-    </message>
     <message>
         <location filename="../stacer/app.ui" line="390"/>
         <source>Gnome Settings</source>
@@ -201,7 +206,7 @@
     <message>
         <location filename="../stacer/app.cpp" line="108"/>
         <location filename="../stacer/app.cpp" line="115"/>
-        <location filename="../stacer/app.cpp" line="168"/>
+        <location filename="../stacer/app.cpp" line="173"/>
         <source>Quit</source>
         <translation>Avsluta</translation>
     </message>
@@ -210,6 +215,11 @@
         <source>Continue</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../stacer/app.cpp" line="113"/>
+        <source>Don&apos;t ask again.</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../stacer/app.cpp" line="116"/>
         <source>Will the program continue to work in the system tray?</source>
@@ -386,16 +396,16 @@
         <source>CPU Model: %1</source>
         <translation>CPU-modell: %1</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="117"/>
-        <source>CPU Speed: %1</source>
-        <translation>CPU-hastighet: %1</translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="116"/>
         <source>CPU Core: %1</source>
         <translation>CPU-kärnor: %1</translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="117"/>
+        <source>CPU Speed: %1</source>
+        <translation>CPU-hastighet: %1</translation>
+    </message>
     <message>
         <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="135"/>
         <source>High CPU Usage</source>
@@ -455,11 +465,6 @@
         <source>Send</source>
         <translation>Skicka</translation>
     </message>
-    <message>
-        <location filename="../stacer/feedback.ui" line="117"/>
-        <source>danger</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/feedback.ui" line="120"/>
         <source>Close</source>
@@ -483,7 +488,7 @@
     <message>
         <location filename="../stacer/feedback.cpp" line="51"/>
         <source>Your message must be at least 5 characters !</source>
-        <translation>Det meddelande måste innehålla minst 25 tecken! {5 ?}</translation>
+        <translation>Det meddelande måste innehålla minst 5 tecken!</translation>
     </message>
     <message>
         <location filename="../stacer/feedback.cpp" line="59"/>
@@ -550,54 +555,11 @@
 </context>
 <context>
     <name>HostManage</name>
-    <message>
-        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="26"/>
-        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="100"/>
-        <source>Hosts (%1)</source>
-        <translation>Värdnamn (%1)</translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="39"/>
-        <source>IP Address</source>
-        <translation>IP-adress</translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="39"/>
-        <source>Full Qualified</source>
-        <translation>Kvalificerat namn</translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="160"/>
-        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="39"/>
-        <source>Aliases</source>
-        <translation>Alias</translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="137"/>
-        <source>Edit</source>
-        <translation>Redigera</translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="141"/>
-        <source>Delete</source>
-        <translation>Ta bort</translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="149"/>
-        <source>The IP and Fully Qualified fields are required.</source>
-        <translation>IP och fullt kvalificerad krävs.</translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.ui" line="14"/>
         <source>Form</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="60"/>
-        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="173"/>
-        <source>primary</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.ui" line="63"/>
         <source>Save Changes</source>
@@ -618,21 +580,53 @@
         <source>Fully Qualified Name *</source>
         <translation>Fullt kvalificerat namn *</translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="160"/>
+        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="39"/>
+        <source>Aliases</source>
+        <translation>Alias</translation>
+    </message>
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.ui" line="176"/>
         <source>Save</source>
         <translation>Spara</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="189"/>
-        <source>danger</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.ui" line="192"/>
         <source>Cancel</source>
         <translation>Avbryt</translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="26"/>
+        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="100"/>
+        <source>Hosts (%1)</source>
+        <translation>Värdnamn (%1)</translation>
+    </message>
+    <message>
+        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="39"/>
+        <source>IP Address</source>
+        <translation>IP-adress</translation>
+    </message>
+    <message>
+        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="39"/>
+        <source>Full Qualified</source>
+        <translation>Kvalificerat namn</translation>
+    </message>
+    <message>
+        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="137"/>
+        <source>Edit</source>
+        <translation>Redigera</translation>
+    </message>
+    <message>
+        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="141"/>
+        <source>Delete</source>
+        <translation>Ta bort</translation>
+    </message>
+    <message>
+        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="149"/>
+        <source>The IP and Fully Qualified fields are required.</source>
+        <translation>IP och fullt kvalificerad krävs.</translation>
+    </message>
 </context>
 <context>
     <name>ProcessesPage</name>
@@ -657,6 +651,11 @@
         <source>End Process</source>
         <translation>Avsluta process</translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="30"/>
+        <source>User</source>
+        <translation>Användare</translation>
+    </message>
     <message>
         <location filename="../stacer/Pages/Processes/processes_page.cpp" line="29"/>
         <source>Resident Memory</source>
@@ -672,11 +671,6 @@
         <source>Virtual Memory</source>
         <translation>Virtuellt minne</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="30"/>
-        <source>User</source>
-        <translation>Användare</translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Processes/processes_page.cpp" line="30"/>
         <source>Start Time</source>
@@ -831,23 +825,6 @@
         <source>Search...</source>
         <translation>Sök...</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="145"/>
-        <source>primary</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="208"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="367"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="403"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="511"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="527"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="543"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="581"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="604"/>
-        <source>circle</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="211"/>
         <source>Case Insensitive</source>
@@ -878,6 +855,12 @@
         <source>Permissions</source>
         <translation>Rättigheter</translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/Search/search_page.ui" line="490"/>
+        <location filename="../stacer/Pages/Search/search_page.cpp" line="27"/>
+        <source>Size</source>
+        <translation>Storlek</translation>
+    </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="514"/>
         <source>Readable</source>
@@ -933,12 +916,6 @@
         <source>Path</source>
         <translation>Sökväg</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="490"/>
-        <location filename="../stacer/Pages/Search/search_page.cpp" line="27"/>
-        <source>Size</source>
-        <translation>Storlek</translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.cpp" line="28"/>
         <source>User</source>
@@ -1151,6 +1128,11 @@
         <source>Disk Percent</source>
         <translation>Diskanvändning</translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/Settings/settings_page.ui" line="329"/>
+        <source>App Quit Don&apos;t Ask</source>
+        <translation>Fråga inte vid avslut</translation>
+    </message>
     <message>
         <location filename="../stacer/Pages/Settings/settings_page.ui" line="389"/>
         <source>Disks</source>
@@ -1181,11 +1163,6 @@
         <source>CPU Percent</source>
         <translation>CPU-belastning</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Settings/settings_page.ui" line="329"/>
-        <source>App Quit Don&apos;t Ask</source>
-        <translation>Fråga inte vid avslut</translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Settings/settings_page.ui" line="267"/>
         <source>Donate</source>
@@ -1300,6 +1277,11 @@
 </context>
 <context>
     <name>StartupAppsPage</name>
+    <message>
+        <location filename="../stacer/Pages/StartupApps/startup_apps_page.ui" line="201"/>
+        <source>Not Found Startup Apps</source>
+        <translation>Inga uppstartsprogram hittades</translation>
+    </message>
     <message>
         <location filename="../stacer/Pages/StartupApps/startup_apps_page.ui" line="14"/>
         <source>Startup Apps</source>
@@ -1311,17 +1293,12 @@
         <translation>Lägg till uppstartsprogram</translation>
     </message>
     <message>
-        <location filename="../stacer/Pages/StartupApps/startup_apps_page.ui" line="201"/>
-        <source>Not Found Startup Apps</source>
-        <translation>Inga uppstartsprogram hittades</translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="66"/>
+        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="67"/>
         <source>Startup Apps are disabled.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="126"/>
+        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="127"/>
         <source>Startup Applications (%1)</source>
         <translation>Uppstartsprogram (%1)</translation>
     </message>
@@ -1364,12 +1341,6 @@
         <source>Select all</source>
         <translation>Markera alla</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="574"/>
-        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="635"/>
-        <source>circle</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="651"/>
         <source> Back</source>
@@ -1411,28 +1382,11 @@
 </context>
 <context>
     <name>UninstallerPage</name>
-    <message>
-        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="340"/>
-        <source>Uninstall Selected</source>
-        <translation>Avinstallera markerat</translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="108"/>
-        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="231"/>
-        <source>Not Found Installed Packages</source>
-        <translation>Inga installerade paket hittades</translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="14"/>
         <source>Uninstaller</source>
         <translation>Avinstallerare</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="78"/>
-        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="201"/>
-        <source>notFoundWidget</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="371"/>
         <source>System Packages</source>
@@ -1448,6 +1402,17 @@
         <source>Search...</source>
         <translation>Sök...</translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="108"/>
+        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="231"/>
+        <source>Not Found Installed Packages</source>
+        <translation>Inga installerade paket hittades</translation>
+    </message>
+    <message>
+        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="340"/>
+        <source>Uninstall Selected</source>
+        <translation>Avinstallera markerat</translation>
+    </message>
     <message>
         <location filename="../stacer/Pages/Uninstaller/uninstaller_page.cpp" line="102"/>
         <source>Packages (%1)</source>
