@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="zh_TW">
+<TS version="2.1" language="zh_TW" sourcelanguage="en">
 <context>
     <name>APTSourceEdit</name>
     <message>
@@ -45,7 +45,7 @@
     </message>
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="133"/>
-        <source>Distribution</source>
+        <source>Suites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -61,16 +61,6 @@
 </context>
 <context>
     <name>APTSourceManagerPage</name>
-    <message>
-        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="14"/>
-        <source>APT Repository Manager</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="125"/>
-        <source>Not Found APT Repositories</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="188"/>
         <source>Search...</source>
@@ -81,6 +71,16 @@
         <source>Edit</source>
         <translation>編輯</translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="14"/>
+        <source>APT Repository Manager</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="125"/>
+        <source>Not Found APT Repositories</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="269"/>
         <source>Delete</source>
@@ -93,7 +93,7 @@
     </message>
     <message>
         <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="338"/>
-        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="85"/>
+        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="95"/>
         <source>Add Repository</source>
         <translation type="unfinished"></translation>
     </message>
@@ -113,15 +113,20 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="58"/>
+        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="63"/>
         <source>APT Repositories (%1)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="65"/>
+        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="69"/>
         <source>Save</source>
         <translation>儲存</translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="75"/>
+        <source>Adding...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>APTSourceRepositoryItem</name>
@@ -148,6 +153,11 @@
         <source>System Cleaner</source>
         <translation>系統清理</translation>
     </message>
+    <message>
+        <location filename="../stacer/app.ui" line="194"/>
+        <source>Search</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../stacer/app.ui" line="278"/>
         <source>Uninstaller</source>
@@ -158,21 +168,6 @@
         <source>Resources</source>
         <translation>系統資源</translation>
     </message>
-    <message>
-        <location filename="../stacer/app.ui" line="250"/>
-        <source>Processes</source>
-        <translation>處理程序</translation>
-    </message>
-    <message>
-        <location filename="../stacer/app.ui" line="194"/>
-        <source>Search</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../stacer/app.ui" line="222"/>
-        <source>Services</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/app.ui" line="334"/>
         <source>Helpers</source>
@@ -183,6 +178,16 @@
         <source>APT Repository Manager</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../stacer/app.ui" line="250"/>
+        <source>Processes</source>
+        <translation>處理程序</translation>
+    </message>
+    <message>
+        <location filename="../stacer/app.ui" line="222"/>
+        <source>Services</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../stacer/app.ui" line="390"/>
         <source>Gnome Settings</source>
@@ -201,7 +206,7 @@
     <message>
         <location filename="../stacer/app.cpp" line="108"/>
         <location filename="../stacer/app.cpp" line="115"/>
-        <location filename="../stacer/app.cpp" line="168"/>
+        <location filename="../stacer/app.cpp" line="173"/>
         <source>Quit</source>
         <translation type="unfinished"></translation>
     </message>
@@ -210,6 +215,11 @@
         <source>Continue</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../stacer/app.cpp" line="113"/>
+        <source>Don&apos;t ask again.</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../stacer/app.cpp" line="116"/>
         <source>Will the program continue to work in the system tray?</source>
@@ -386,16 +396,16 @@
         <source>CPU Model: %1</source>
         <translation>CPU 型號: %1</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="117"/>
-        <source>CPU Speed: %1</source>
-        <translation>CPU 時脈: %1</translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="116"/>
         <source>CPU Core: %1</source>
         <translation>CPU 核心: %1</translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="117"/>
+        <source>CPU Speed: %1</source>
+        <translation>CPU 時脈: %1</translation>
+    </message>
     <message>
         <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="135"/>
         <source>High CPU Usage</source>
@@ -440,11 +450,6 @@
         <source>Feedback</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../stacer/feedback.ui" line="54"/>
-        <source>Message</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/feedback.ui" line="61"/>
         <source>Name</source>
@@ -455,24 +460,24 @@
         <source>Email Address</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../stacer/feedback.ui" line="78"/>
-        <source>Send feedback</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/feedback.ui" line="97"/>
         <source>Send</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../stacer/feedback.ui" line="117"/>
-        <source>danger</source>
+        <location filename="../stacer/feedback.ui" line="120"/>
+        <source>Close</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../stacer/feedback.ui" line="120"/>
-        <source>Close</source>
+        <location filename="../stacer/feedback.ui" line="54"/>
+        <source>Message</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../stacer/feedback.ui" line="78"/>
+        <source>Send feedback</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -555,12 +560,6 @@
         <source>Form</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="60"/>
-        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="173"/>
-        <source>primary</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.ui" line="63"/>
         <source>Save Changes</source>
@@ -592,11 +591,6 @@
         <source>Save</source>
         <translation>儲存</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="189"/>
-        <source>danger</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Helpers/host_manage.ui" line="192"/>
         <source>Cancel</source>
@@ -733,11 +727,6 @@
 </context>
 <context>
     <name>ResourcesPage</name>
-    <message>
-        <location filename="../stacer/Pages/Resources/resources_page.ui" line="14"/>
-        <source>Resources</source>
-        <translation>系統資源</translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Resources/resources_page.cpp" line="14"/>
         <source>History of CPU</source>
@@ -813,6 +802,11 @@
         <source>Memory: %1 (%2%) %3</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/Resources/resources_page.ui" line="14"/>
+        <source>Resources</source>
+        <translation>系統資源</translation>
+    </message>
 </context>
 <context>
     <name>SearchPage</name>
@@ -831,23 +825,6 @@
         <source>Search...</source>
         <translation>搜尋...</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="145"/>
-        <source>primary</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="208"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="367"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="403"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="511"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="527"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="543"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="581"/>
-        <location filename="../stacer/Pages/Search/search_page.ui" line="604"/>
-        <source>circle</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Search/search_page.ui" line="211"/>
         <source>Case Insensitive</source>
@@ -1151,31 +1128,6 @@
         <source>Disk Percent</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Settings/settings_page.ui" line="158"/>
-        <source>Language</source>
-        <translation>語言</translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Settings/settings_page.ui" line="171"/>
-        <source>Autostart Stacer</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Settings/settings_page.ui" line="213"/>
-        <source>CPU Percent</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Settings/settings_page.ui" line="229"/>
-        <source>Alert messages (Show a warning after the specified percentage)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Settings/settings_page.ui" line="267"/>
-        <source>Donate</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Settings/settings_page.ui" line="329"/>
         <source>App Quit Don&apos;t Ask</source>
@@ -1186,11 +1138,36 @@
         <source>Disks</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/Settings/settings_page.ui" line="158"/>
+        <source>Language</source>
+        <translation>語言</translation>
+    </message>
+    <message>
+        <location filename="../stacer/Pages/Settings/settings_page.ui" line="171"/>
+        <source>Autostart Stacer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../stacer/Pages/Settings/settings_page.ui" line="229"/>
+        <source>Alert messages (Show a warning after the specified percentage)</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../stacer/Pages/Settings/settings_page.ui" line="402"/>
         <source>Start Page</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/Settings/settings_page.ui" line="213"/>
+        <source>CPU Percent</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../stacer/Pages/Settings/settings_page.ui" line="267"/>
+        <source>Donate</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../stacer/Pages/Settings/settings_page.cpp" line="83"/>
         <source>Dashboard</source>
@@ -1221,11 +1198,6 @@
         <source>Processes</source>
         <translation>處理程序</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Settings/settings_page.cpp" line="84"/>
-        <source>Helpers</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Settings/settings_page.cpp" line="84"/>
         <source>Uninstaller</source>
@@ -1236,6 +1208,11 @@
         <source>Resources</source>
         <translation>系統資源</translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/Settings/settings_page.cpp" line="84"/>
+        <source>Helpers</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StartupApp</name>
@@ -1300,28 +1277,28 @@
 </context>
 <context>
     <name>StartupAppsPage</name>
-    <message>
-        <location filename="../stacer/Pages/StartupApps/startup_apps_page.ui" line="14"/>
-        <source>Startup Apps</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/StartupApps/startup_apps_page.ui" line="201"/>
         <source>Not Found Startup Apps</source>
         <translation>沒有找到系統開機啟動項目</translation>
     </message>
+    <message>
+        <location filename="../stacer/Pages/StartupApps/startup_apps_page.ui" line="14"/>
+        <source>Startup Apps</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../stacer/Pages/StartupApps/startup_apps_page.ui" line="101"/>
         <source>Add Startup App</source>
         <translation>加入系統開機啟動項目</translation>
     </message>
     <message>
-        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="66"/>
+        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="67"/>
         <source>Startup Apps are disabled.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="126"/>
+        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="127"/>
         <source>Startup Applications (%1)</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1364,12 +1341,6 @@
         <source>Select all</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="574"/>
-        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="635"/>
-        <source>circle</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="651"/>
         <source> Back</source>
@@ -1411,6 +1382,21 @@
 </context>
 <context>
     <name>UninstallerPage</name>
+    <message>
+        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="14"/>
+        <source>Uninstaller</source>
+        <translation>解除安裝</translation>
+    </message>
+    <message>
+        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="371"/>
+        <source>System Packages</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="393"/>
+        <source>Snap Packages</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="442"/>
         <source>Search...</source>
@@ -1422,32 +1408,11 @@
         <source>Not Found Installed Packages</source>
         <translation>未發現已安裝的套件</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="14"/>
-        <source>Uninstaller</source>
-        <translation>解除安裝</translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="78"/>
-        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="201"/>
-        <source>notFoundWidget</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="340"/>
         <source>Uninstall Selected</source>
         <translation>解除安裝選中的項目</translation>
     </message>
-    <message>
-        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="371"/>
-        <source>System Packages</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="393"/>
-        <source>Snap Packages</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../stacer/Pages/Uninstaller/uninstaller_page.cpp" line="102"/>
         <source>Packages (%1)</source>
